# What's Changed

0. ✨ 新增: 支持 海豚 AI（FishAudio） TTS API #433 by @Cvandia
1. 🐛 修复: 当群聊主动回复时，不会带上人格的Prompt #419
2. ✨ 新增: 支持展示插件是否有更新
3. 👌 优化: 增加DIFY超时时间 #422
4. 🐛 修复: 自部署文转图不生效 #352
5. 🐛 修复: 修复 qq 回复别人的时候也会触发机器人, Onebot at 使用 string #330
6. 👌 优化: 增加DIFY超时时间 #422
7. 🐛 修复: 重启gewe的时候机器人会疯狂发消息 #421
8. 🐛 修复: 修复子指令设置permission之后会导致其一定会被执行 #427